@@ -2,7 +2,7 @@ from spym.process import filters as spym_filters
 
 class SpymFilters():
     ''' Filters.
-    
+
     '''
 
     def __init__(self, spym_instance):
@@ -13,6 +13,7 @@ class SpymFilters():
 
         Args:
             size: size of the filter in pixels.
+
         '''
 
         self._spym._dr.data = spym_filters.gauss(self._spym._dr.data, **kwargs)
@@ -22,6 +23,7 @@ class SpymFilters():
 
         Args:
             size: size of the filter in pixels.
+
         '''
 
         self._spym._dr.data = spym_filters.median(self._spym._dr.data, **kwargs)
@@ -31,6 +33,7 @@ class SpymFilters():
 
         Args:
             size: size of the filter in pixels.
+
         '''
 
         self._spym._dr.data = spym_filters.mean(self._spym._dr.data, **kwargs)
@@ -41,25 +44,24 @@ class SpymFilters():
         Args:
             size: size of the filter in pixels.
             alpha: weight.
+
         '''
 
         self._spym._dr.data = spym_filters.sharpen(self._spym._dr.data, **kwargs)
 
     def destripe(self, **kwargs):
-        ''' Find and remove scan stripes by averaging neighbourhood lines
+        ''' Find and remove scan stripes by averaging neighbourhood lines.
 
         Args:
-            min_length: only scars that are as long or longer than this value (in pixels) will be marked
-            hard_threshold: the minimum difference of the value from the neighbouring upper and lower lines
-                to be considered a defect.
-            soft_threshold: values differing at least this much do not form defects themselves,
-                but they are attached to defects obtained from the hard threshold if they touch one.
+            min_length: only scars that are as long or longer than this value (in pixels) will be marked.
+            hard_threshold: the minimum difference of the value from the neighbouring upper and lower lines to be considered a defect.
+            soft_threshold: values differing at least this much do not form defects themselves, but they are attached to defects obtained from the hard threshold if they touch one.
             sign: whether mark stripes with positive values, negative values or both.
-            rel_threshold: the minimum difference of the value from the neighbouring upper and
-                lower lines to be considered a defect (in physical values). Overwrite hard_threshold.
+            rel_threshold: the minimum difference of the value from the neighbouring upper and lower lines to be considered a defect (in physical values). Overwrite hard_threshold.
 
         Returns:
-            destriped 2d array
+            destriped 2d array.
+
         '''
 
         if not self._spym._dr.data.ndim == 2:
